# 20230517_v0.9.13_large_offset

DL1 production of the test node for IRF using gamma diffuse MC

lstchain config taken from '20230127_v0.9.12_base_prod_az_tel'

Contact : Mathieu de Bony, Léo Le Moigne, David Sanchez


